@@ -1,7 +1,7 @@
 user.info <-
 function(token=NA,consumer_key=NA,consumer_secret=NA){
   
-  if(class(token)!="Token1.0")
+  if(class(token)[1]!="Token1.0")
     stop("token must be a Token1.0 type")
   
   if(!is.character(consumer_key))
